@@ -10,9 +10,10 @@ Currently, it determines the average response time of a host.
 import re
 from jabbapylib.process import process
 
-def ping(url, cnt=1):
+
+def ping(host, cnt=1):
     """Ping a URL and return the average ping time."""
-    cmd = 'ping -c {cnt} {url}'.format(url=url, cnt=cnt)
+    cmd = 'ping -c {cnt} {url}'.format(url=host, cnt=cnt)
     output = [x for x in process.get_simple_cmd_output(cmd).split('\n') if x]
     result = re.search('min/avg/max/mdev = (.*)/(.*)/(.*)/(.*) ms', output[-1])
     if result:
@@ -20,8 +21,24 @@ def ping(url, cnt=1):
     else:
         return None
 
+
+def fping(host, cnt=1):
+    """
+    Get the avg ping time of a host (in msec).
+
+    Instead of ping we use the command fping.
+    """
+    host = host.split(':')[0]
+    cmd = "fping {host} -C {cnt} -q".format(host=host, cnt=cnt)
+    res = [float(x) for x in process.get_simple_cmd_output(cmd).strip().split(':')[-1].split() if x != '-']
+    if len(res) > 0:
+        return sum(res) / len(res)
+    else:
+        return None
+
 #############################################################################
     
 if __name__ == "__main__":
-    url = 'www.google.com'
-    print ping(url)
\ No newline at end of file
+    host = 'www.google.com'
+    print ping(host, 2)
+    print fping(host, 2)
\ No newline at end of file
