@@ -8,6 +8,7 @@ sudo apt-get install \
     libxml2-dev \
     libxslt-dev \
     lynx \
+    lynx-cur \
     mplayer2 \
     python-imaging \
     python-lxml \
@@ -16,7 +17,13 @@ sudo apt-get install \
     python2.7-dev \
     python-xlib \
     sqlite3 \
-    tesseract-ocr \
     tidy \
     xsel \
-    bsdgames
+    bsdgames \
+    fping \
+    libmpfr-dev \
+    libgmp3-dev
+
+# tesseract-ocr was removed
+# you'd better install it from source
+# the one in the Ubuntu repo. is very old
