@@ -1,3 +1,4 @@
+import re
 from jabbapylib.platform import platform
 from jabbapylib.filesystem import fs
 
@@ -19,3 +20,7 @@ def test_get_screen_resolution():
     result = platform.get_screen_resolution()
     assert len(result) == 2
     assert result[0] > 0 and result[1] > 0
+
+def test_get_firefox_profile_folder():
+    result = platform.get_firefox_profile_folder()
+    assert re.search('.*/.{8}\.default$', result)
\ No newline at end of file
