@@ -6,4 +6,4 @@ def test_hyphen():
     res = hyphen.process(word)
     assert res[0] == 'python'
     assert res[1] == 'py-thon'
-    assert res[2] == 'http://sp.dictionary.com/dictstatic/dictionary/audio/luna/P09/P0975800.mp3'
\ No newline at end of file
+    assert res[2] == 'http://static.sfdict.com/dictstatic/dictionary/audio/luna/P09/P0975800.mp3'
\ No newline at end of file
